@@ -168,7 +168,7 @@ typedef TQValueList<TQByteArray> TQByteArrayList;
 typedef TQPair<uint32_t, TQByteArray> PKICertificateEntry;
 typedef TQValueList<PKICertificateEntry> PKICertificateEntryList;
 
-class KDE_EXPORT LDAPCredentials
+class TDE_EXPORT LDAPCredentials
 {
 	public:
 		LDAPCredentials();
@@ -185,7 +185,7 @@ class KDE_EXPORT LDAPCredentials
 };
 
 // PRIVATE
-class KDE_EXPORT LDAPRealmConfig
+class TDE_EXPORT LDAPRealmConfig
 {
 	public:
 		TQString name;
@@ -205,7 +205,7 @@ class KDE_EXPORT LDAPRealmConfig
 };
 
 // PRIVATE
-class KDE_EXPORT LDAPCertConfig
+class TDE_EXPORT LDAPCertConfig
 {
 	public:
 		LDAPCertConfig();
@@ -235,7 +235,7 @@ class KDE_EXPORT LDAPCertConfig
 };
 
 // PRIVATE
-class KDE_EXPORT LDAPPamConfig
+class TDE_EXPORT LDAPPamConfig
 {
 	public:
 		LDAPPamConfig();
@@ -251,7 +251,7 @@ class KDE_EXPORT LDAPPamConfig
 };
 
 // PRIVATE
-class KDE_EXPORT LDAPClientRealmConfig
+class TDE_EXPORT LDAPClientRealmConfig
 {
 	public:
 		bool enable_bonding;
@@ -274,7 +274,7 @@ class KDE_EXPORT LDAPClientRealmConfig
 
 typedef TQMap<TQString, LDAPRealmConfig> LDAPRealmConfigList;
 
-class KDE_EXPORT LDAPUserInfo
+class TDE_EXPORT LDAPUserInfo
 {
 	public:
 		LDAPUserInfo();
@@ -357,7 +357,7 @@ class KDE_EXPORT LDAPUserInfo
 		PKICertificateEntryList pkiCertificates;
 };
 
-class KDE_EXPORT LDAPGroupInfo
+class TDE_EXPORT LDAPGroupInfo
 {
 	public:
 		LDAPGroupInfo();
@@ -374,7 +374,7 @@ class KDE_EXPORT LDAPGroupInfo
 		TQStringList userlist;
 };
 
-class KDE_EXPORT LDAPMachineInfo
+class TDE_EXPORT LDAPMachineInfo
 {
 	public:
 		LDAPMachineInfo();
@@ -391,7 +391,7 @@ class KDE_EXPORT LDAPMachineInfo
 		LDAPKRB5Flags status;		// Default is 126 [KRB5_MACHINE_ACCOUNT_DEFAULT]
 };
 
-class KDE_EXPORT LDAPServiceInfo
+class TDE_EXPORT LDAPServiceInfo
 {
 	public:
 		LDAPServiceInfo();
@@ -409,7 +409,7 @@ class KDE_EXPORT LDAPServiceInfo
 		LDAPKRB5Flags status;		// Default is 126 [KRB5_SERVICE_PRINCIPAL_DEFAULT]
 };
 
-class KDE_EXPORT LDAPTDEBuiltinsInfo
+class TDE_EXPORT LDAPTDEBuiltinsInfo
 {
 	public:
 		LDAPTDEBuiltinsInfo();
@@ -423,7 +423,7 @@ class KDE_EXPORT LDAPTDEBuiltinsInfo
 		TQString builtinStandardUserGroup;
 };
 
-class KDE_EXPORT LDAPMasterReplicationMapping
+class TDE_EXPORT LDAPMasterReplicationMapping
 {
 	public:
 		LDAPMasterReplicationMapping();
@@ -436,7 +436,7 @@ class KDE_EXPORT LDAPMasterReplicationMapping
 
 typedef TQValueList<LDAPMasterReplicationMapping> LDAPMasterReplicationMap;
 
-class KDE_EXPORT LDAPMasterReplicationInfo
+class TDE_EXPORT LDAPMasterReplicationInfo
 {
 	public:
 		LDAPMasterReplicationInfo();
@@ -457,7 +457,7 @@ class KDE_EXPORT LDAPMasterReplicationInfo
 		bool replicate_olcGlobal;
 };
 
-class KDE_EXPORT KerberosTicketInfo
+class TDE_EXPORT KerberosTicketInfo
 {
 	public:
 		KerberosTicketInfo();
@@ -488,8 +488,8 @@ typedef TQValueList<KerberosTicketInfo> KerberosTicketInfoList;
 
 class PtyProcess;
 
-class KDE_EXPORT LDAPManager : public TQObject {
-	Q_OBJECT
+class TDE_EXPORT LDAPManager : public TQObject {
+	TQ_OBJECT
 
 	public:
 		LDAPManager(TQString realm, TQString host, TQObject *parent=0, const char *name=0);
